/*
 * File:   Main_GSM_BOX.c
 * Author: Francesco
 *
 * Created on 23 dicembre 2012, 11.35
 * Project name:
                Telecontrollo GSM  MC35iT
 * Test configuration:
     MCU:             P18F4620
     Oscillator:      INTERNO, 8.0000 MHz
 * NOTES:

 ********************************************************************
Sequenze di Escape:
Sequenza Nome del carattere
\a       campanello
\b       backspace
\f       FF - form feed (salto pagina)
\n       LF - line feed o newline
\r       CR - carriage return (ritorno del carrello)
\t       tabulazione orizzontale
\v       tabulazione verticale
\\       \ (barra inversa)
\?       ? (punto interrogativo)
\'       ' (apice)
\"       " (doppi apici)
\0       NULL (carattere nullo o di fine stringa)
 **********************************************************************


 * CONFIGURAZIONE PERIFERICHE


 * MCLR    -> Disabilitato.
 * CLK     -> INTERNO 8MHz
 * OUT     -> PORTA A

 * LIBERO  -> PORT C.3


 * RELAY   -> PORT C.4
 * RELAY   -> PORT C.5

 * UART    -> PORT C.6 : TX
 *            PORT C.7 : RX

 * LED     -> PORT A.0
 * LED     -> PORT A.1
 * LED     -> PORT A.2
 * LED     -> PORT A.3
 * LED     -> PORT A.4
 * LED     -> PORT A.5
 * LED     -> PORT A.6
 * LED     -> PORT A.7

 * IN1     -> PORT B.0  -> Apertura BOX
 * IN2     -> PORT B.1
 * IN3     -> PORT B.2  -> read setup switch


 * INSETUP1-> PORT B.3  -> On -Off Modem GSM
 * INSETUP2-> PORT B.4

 * SINTASSI SMS:
 * +CMGR: "REC READ","+393472626883",,"09/12/19,17:36:58+04"Invio prova controllo s1

 * Sent: AT+CPBR=1,10

 * +CPBR: 1,"+393472626883",145,"Francesco"
 * +CPBR: 2,"+393479630905",145,"Eleonora"
 * +CPBR: 3,"1234",129,"Utente3"
 * +CPBR: 4,"12345",129,"Utente4"
 * +CPBR: 5,"123456",129,"Utente5"
 * +CPBR: 6,"987654",129,"Utente6"

 * RICEVE SMS:          +CMTI: "MT",1
 * RICEVE CHIAMATA :    RING  +CLIP: "+393472626883", 145,,,,0

 */
#include <htc.h>

#include "function.h"
#include <delays.h>             // library containing delays - i.e. wait for time t
#include <string.h>
#include <p18cxxx.h>


//****************     AT commands     *******************


const char AT[] = "AT\r"; /* risposta da provare per sincronizzare autobauding*/
const char AT_FlowControl[] = "AT\\Q0\r"; /* risposta OK */
const char AT_DisconnectCall[] = "ATH0\r"; /* risposta OK  or NO CARRIER*/
const char AT_EchoOFF[] = "ATE0\r"; /* risposta OK */

//***************   CALL  AT COMMAND    ******************************

const char AT_CALL_SM1[] = "ATD>SM1;\r"; /* Chiama Utente in posizione 1 sim  */
const char AT_CALL_SM2[] = "ATD>SM2;\r"; /* Chiama Utente in posizione 2 sim  */

const char AT_CALL_CLOSE[] = "ATH\r"; /* Termina chiamata   */

//***************   SIM AT COMMAND    ******************************

const char AT_SIM_READ1[] = "AT+CPBR=1,1\r";
const char AT_SIM_READ2[] = "AT+CPBR=2,2\r";
const char AT_SIM_READ3[] = "AT+CPBR=3,3\r";
const char AT_SIM_READ4[] = "AT+CPBR=4,4\r";
const char AT_SIM_READ5[] = "AT+CPBR=5,5\r";
const char AT_SIM_READ6[] = "AT+CPBR=6,6\r";
const char AT_SIM_READ7[] = "AT+CPBR=7,7\r";
const char AT_SIM_READ8[] = "AT+CPBR=8,8\r";
const char AT_SIM_READ9[] = "AT+CPBR=9,9\r";
const char AT_SIM_READ10[] = "AT+CPBR=10,10\r";

//***************   GENERAL AT COMMAND    ******************************

const char AT_URC_CALL[] = "AT+CLIP=1\r"; // risposta  OK
const char AT_URC_SMS[] = "AT+CNMI=1,1\r"; // risposta  OK

const char AT_Switch_OFF[] = "AT^SMSO\r"; // risposta ^SMSO: MS OFF OK

//***************   SMS AT COMMAND    ******************************

const char AT_SMS_TEXT[] = "AT+CMGF=1\r"; // risposta SMS = TEXT  *
const char AT_SMS_DEL[] = "AT+CMGD=1\r"; // Canceslla SMS in posizione 1 della memoria *
const char AT_SMS_READ[] = "AT+CMGR=1\r"; // Legge SMS in posizione 1 della memoria

const char AT_SEND_SMS1[] = "AT+CMGS=\"+"; // risposta > deve segure messaggio di testo Ctrl+Z
const char AT_SEND_SMS2[] = "\"\r"; // prima bisogna mandare il N di telefono


//************** variable declaration
unsigned char SMS[] = "+CMTI";
unsigned char CALL[] = "+CLIP";

unsigned char GSM_BUFF[20]; //declare receive buffer
unsigned char GSM_BUFF_URC[100];
unsigned char GSM_BUFF_SIM[100];
unsigned char GSM_BUFF_SMS[200];
unsigned char USER1[15];
unsigned char USER2[15];
unsigned char USER3[15];
unsigned char USER4[15];
unsigned char USER5[15];
unsigned char USER6[15];
unsigned char USER7[15];
unsigned char USER8[15];
unsigned char USER9[15];
unsigned char USER10[15];

unsigned char GSM_SMS_SEND[] = "OUT: R1=X R2=X  IN: I0=X I1=X I2=X I3=X I4=X \r\n"; //declare receive buffer

unsigned int i, x, y, User, INT_AVVENUTO, URC_SMS, URC_CALL;
unsigned int Utente1, Utente2, Utente3, Utente4, Utente5, Utente6, Utente7, Utente8, Utente9, Utente10;
int Command_len, Relayout=0, User_len, input;
unsigned char SMS_char;

// Interrupt vector

void interrupt int_routine(void) {
    //**********  DISABILITARE INTERUPT ***************************
    INTCONbits.GIE = 0; //disable all un-masked interrupts
    INTCONbits.PEIE = 0; //che ti abilita l'interrupt delle periferiche
    PIE1bits.RCIE = 0;  //EUSART Receive Interrupt Enable bit
    INTCONbits.INT0IE = 0;    //che ti abilita l'interrupt sui pin esterni
    INTCON3bits.INT1IE = 0;   //  INT1 External Interrupt Enable bit
    INTCON3bits.INT2IE = 0;   //  INT2 External Interrupt Enable bit
   //INTCONbits.RBIE = 0;  //  RB Port Change Interrupt Enable bit

    if (PIR1bits.RCIF == 1) {
        //tuo codice
        INT_AVVENUTO = 1;
        PIR1bits.RCIF = 0;
    }
    else if(INTCONbits.INT0IF ==1){
        //tuo codice
        INT_AVVENUTO =2;
        INTCONbits.INT0IF=0;
    }
    else if(INTCON3bits.INT1IF ==1){
        //tuo codice
        INT_AVVENUTO =3;
        INTCON3bits.INT1IF=0;
    }
    else if(INTCON3bits.INT2IF ==1){
        //tuo codice
        INT_AVVENUTO =4;
        INTCON3bits.INT2IF=0;
    }
    else {

    }

}

void main(void) {
    TRISA = 0x00; // PORTA is output
    LATA = 0;
    PORTA = 0; // initialize PORT .
      
    TRISB = 0xFF; // PORTB is input
    LATB = 0;

    TRISC = 0x00; // PORTA is output
    LATC = 0;
    PORTC = 0; // initialize PORT .

    OSCCONbits.IRCF0 = 1; // setting CK interno a 8Mhz
    OSCCONbits.IRCF1 = 1; // setting CK interno a 8Mhz
    OSCCONbits.IRCF2 = 1; // setting CK interno a 8Mhz
    
    //**********  DISABILITARE INTERUPT ***************************

    INTCON2bits.INTEDG0 = 0; // External Interrupt 0 Edge Select bit
    INTCON2bits.INTEDG1 = 0; // External Interrupt 1 Edge Select bit
    INTCON2bits.INTEDG2 = 0; // External Interrupt 2 Edge Select bit
                                 // 0 = Interrupt on falling edge
    INT_AVVENUTO = 0;
    // initialize PORT .

    USARTInit(9600ul, 8);
    Delay10KTCYx(200); // Wait for UART module to stabilize



    //*  Prova **********

    LATA = 0;

    //************  SET baud rate true AT command, speed nogotation *******
    Usart_Write_Text(AT); // send "AT" string until gsm sets up its baud rade
    // ******  sara necessario inserire ciclo di verifica pi time out durante la lettura
    Delay10KTCYx(200);
    //******* disabilito echo
    Usart_Write_Text(AT_EchoOFF); // send AT command for
    //  ******************fine disabilitato echo
    Delay10KTCYx(200);
    //** Setup URC Unsolicited Resul Codes per CHIAMATE  ******
    Usart_Write_Text(AT_URC_CALL); // send AT command for URC SMS

    //** Setup per SMS in formato TEXT  ******
    Usart_Write_Text(AT_SMS_TEXT); // send AT command for TEXT SMS

    //** Setup URC Unsolicited Resul Codes per SMS  ******
    Usart_Write_Text(AT_URC_SMS); // send AT command for URC SMS

    LATA = 1;
    Usart_Read_Text();

    LATA = 0;
    //***************************************************************************

    WaitOneSecond();

    //** Carica i Numeri di telefono abilitati dalla sim in memoria i primi 10 **
    LATA = 8;
    Load_User_SimToRam();
    LATA = 0;
    //***************************************************************************

    LATA = 1;
    Usart_Read_Text();
    LATA = 0;
    
        Usart_Write_Text("attesa int");
        USART_Write_Line(" ");

    while (1) {
        //*********************prova di abilitazione interupt UART *******************
        INTCONbits.GIE = 1; //enable all un-masked interrupts
        INTCONbits.PEIE = 1; //che ti abilita l'interrupt delle periferiche
        INTCONbits.INT0IE = 1; //che ti abilita l'interrupt sui pin esterni

        PIR1bits.RCIF = 0;  //EUSART External Interrupt Enable bit
        PIE1bits.RCIE = 1; //EUSART Receive Interrupt Enable bit
        PIE2 = 0;
        //INTCONbits.RBIF = 0;  //  RB Port Change Interrupt Flag bit(
        INTCONbits.INT0IF = 0;  //  INT0 External Interrupt Enable bit
        INTCON3bits.INT1IF = 0; //  INT1 External Interrupt Enable bit
        INTCON3bits.INT2IF = 0; //  INT2 External Interrupt Enable bit

        //INTCONbits.RBIE = 1;  //  RB Port Change Interrupt Enable bit
        INTCONbits.INT0IE = 1;  //  INT0 External Interrupt Enable bit
        INTCON3bits.INT1IE = 1; //  INT1 External Interrupt Enable bit
        INTCON3bits.INT2IE = 1; //  INT2 External Interrupt Enable bit

        //****************************************************************************


        while (INT_AVVENUTO == 0) {

        }

        switch (INT_AVVENUTO) {
            case 1:
                Int_from_UART();
                WaitOneSecond();
                break;
            case 2:
                Usart_Write_Text("INT0");
                USART_Write_Line(" ");
                Usart_Write_Text(AT_CALL_SM1);
                WaitOneSecond();
                //INTCONbits.INT0IF=0;
                break;
            case 3:
                Usart_Write_Text("INT1");
                USART_Write_Line(" ");
                WaitOneSecond();
                //INTCON3bits.INT1IF=0;
                break;
            case 4:
                Usart_Write_Text("INT2");
                USART_Write_Line(" ");
                if (PORTBbits.RB3 == 0 ){
                    Usart_Write_Text("sw2 on");
                    USART_Write_Line(" ");
                }

                if (PORTBbits.RB4 == 0 ){
                    Usart_Write_Text("sw1 on");
                    USART_Write_Line(" ");
                }
                WaitOneSecond();
                //INTCON3bits.INT2IF=0;
                break;

            default:

                break;
        }

        INT_AVVENUTO = 0;
    }

}



